@@ -4,7 +4,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::Test::ReportPrereqs;
 # ABSTRACT: Report on prerequisite versions during automated testing
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 use Dist::Zilla 4 ();
 use File::Slurp qw/read_file write_file/;
@@ -14,6 +14,22 @@ use Moose;
 extends 'Dist::Zilla::Plugin::InlineFiles';
 with 'Dist::Zilla::Role::AfterBuild';
 
+sub mvp_multivalue_args {
+  return qw( include exclude );
+}
+
+foreach my $attr ( qw( include exclude ) ){
+  has "${attr}s" => (
+    init_arg => $attr,
+    is       => 'ro',
+    traits   => ['Array'],
+    default  => sub { [] },
+    handles  => {
+      "${attr}d_modules" => 'elements',
+    },
+  );
+}
+
 sub after_build {
   my ($self, $opt) = @_;
   my $build_root = $opt->{build_root};
@@ -28,6 +44,14 @@ sub _module_list {
   my $self = shift;
   my $prereqs = $self->zilla->prereqs->as_string_hash;
   my %uniq = map {$_ => 1} map { keys %$_ } map { values %$_ } values %$prereqs;
+
+  if( my @includes = $self->included_modules ){
+    @uniq{ @includes } = (1) x @includes;
+  }
+  if( my @excludes = $self->excluded_modules ){
+    delete @uniq{ @excludes };
+  }
+
   return sort keys %uniq; ## no critic
 }
 
@@ -46,12 +70,14 @@ Dist::Zilla::Plugin::Test::ReportPrereqs - Report on prerequisite versions durin
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
   # in dist.ini
   [Test::ReportPrereqs]
+  include = Acme::FYI
+  exclude = Acme::Dont::Care
 
 =head1 DESCRIPTION
 
@@ -70,6 +96,20 @@ reported as "undef".  If a module is not installed, "missing" is reported
 instead of a version string.
 
 =for Pod::Coverage after_build
+mvp_multivalue_args
+
+=head1 CONFIGURATION
+
+=head2 include
+
+An C<include> attribute can be specified (multiple times) to add modules
+to the report.  This can be useful if there is a module in the dependency
+chain that is problematic but is not directly required by this project.
+
+=head2 exclude
+
+An C<exclude> attribute can be specified (multiple times) to remove
+modules from the report (if you had a reason to do so).
 
 =head1 SEE ALSO
 
